==> intel-graphics-compiler_1.0.0.orig.tar.xz: intel-graphics-compiler-igc-1.0.0/IGC/Compiler/MetaDataApi/IGCMetaDataHelper.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#pragma once

#include "Compiler/MetaDataApi/MetaDataApi.h"
#include "common/MDFrameWork.h"
#include "common/igc_regkeys.hpp"

namespace IGC { namespace IGCMD {

    class IGCMetaDataHelper
    {

    public:
        static void addFunction(MetaDataUtils &mdUtils, llvm::Function *pFunc, IGC::FunctionTypeMD type = IGC::FunctionTypeMD::KernelFunction);

        // In OCL, thread group size (hint) is given by kernel attributes reqd_work_group_size_hint and work_group_size_hint.
        // Return thread group size (hint) if present; return 0 otherwise.
        static uint32_t getThreadGroupSize(MetaDataUtils &mdUtils, llvm::Function *pKernelFunc);
        static uint32_t getThreadGroupSizeHint(MetaDataUtils &mdUtils, llvm::Function *pKernelFunc);
    };

} }

==> intel-graphics-compiler_1.0.6.orig.tar.xz: intel-graphics-compiler-igc-1.0.6/IGC/Compiler/MetaDataApi/IGCMetaDataHelper.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#pragma once

#include "Compiler/MetaDataApi/MetaDataApi.h"
#include "common/MDFrameWork.h"
#include "common/igc_regkeys.hpp"

namespace IGC { namespace IGCMD {

    class IGCMetaDataHelper
    {

    public:
        static void addFunction(MetaDataUtils &mdUtils, llvm::Function *pFunc, IGC::FunctionTypeMD type = IGC::FunctionTypeMD::KernelFunction);

        // In OCL, thread group size (hint) is given by kernel attributes reqd_work_group_size and work_group_size_hint.
        // Return thread group size (hint) if present; return 0 otherwise.
        static uint32_t getThreadGroupSize(MetaDataUtils &mdUtils, llvm::Function *pKernelFunc);
        static uint32_t getThreadGroupSizeHint(MetaDataUtils &mdUtils, llvm::Function *pKernelFunc);
    };

} }
